==> phoenix-5.2.0-src.tar.gz: phoenix-5.2.0/phoenix-core-client/src/main/java/org/apache/phoenix/hbase/index/metrics/MetricsIndexerSourceFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.phoenix.hbase.index.metrics;

/**
 * Factory class for creating {@link MetricsIndexerSource} instances.
 */
public class MetricsIndexerSourceFactory {
  private static final MetricsIndexerSourceFactory INSTANCE = new MetricsIndexerSourceFactory();
  private volatile MetricsIndexerSource indexerSource;
  private GlobalIndexCheckerSource globalIndexCheckerSource;

  private MetricsIndexerSourceFactory() {}

  public static MetricsIndexerSourceFactory getInstance() {
    return INSTANCE;
  }

  public synchronized MetricsIndexerSource getIndexerSource() {
    if (INSTANCE.indexerSource == null) {
      INSTANCE.indexerSource = new MetricsIndexerSourceImpl();
    }
    return INSTANCE.indexerSource;
  }

  public synchronized GlobalIndexCheckerSource getGlobalIndexCheckerSource() {
    if (INSTANCE.globalIndexCheckerSource == null) {
      INSTANCE.globalIndexCheckerSource = new GlobalIndexCheckerSourceImpl();
    }
    return INSTANCE.globalIndexCheckerSource;
  }
}

==> phoenix-5.3.0-src.tar.gz: phoenix-5.3.0/phoenix-core-client/src/main/java/org/apache/phoenix/hbase/index/metrics/MetricsIndexerSourceFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.phoenix.hbase.index.metrics;

/**
 * Factory class for creating {@link MetricsIndexerSource} instances.
 */
public class MetricsIndexerSourceFactory {
  private static final MetricsIndexerSourceFactory INSTANCE = new MetricsIndexerSourceFactory();
  private volatile MetricsIndexerSource indexerSource;
  private GlobalIndexCheckerSource globalIndexCheckerSource;

  private MetricsIndexerSourceFactory() {
  }

  public static MetricsIndexerSourceFactory getInstance() {
    return INSTANCE;
  }

  public synchronized MetricsIndexerSource getIndexerSource() {
    if (INSTANCE.indexerSource == null) {
      INSTANCE.indexerSource = new MetricsIndexerSourceImpl();
    }
    return INSTANCE.indexerSource;
  }

  public synchronized GlobalIndexCheckerSource getGlobalIndexCheckerSource() {
    if (INSTANCE.globalIndexCheckerSource == null) {
      INSTANCE.globalIndexCheckerSource = new GlobalIndexCheckerSourceImpl();
    }
    return INSTANCE.globalIndexCheckerSource;
  }
}
